Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1333)

Unified Diff: src/hydrogen.h

Issue 19595004: Rename AllocationSiteInfo to AllocationMemento (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/heap.cc ('k') | src/hydrogen.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/hydrogen.h
diff --git a/src/hydrogen.h b/src/hydrogen.h
index 19128065970ecfd4d391ba8bed35f98e6d8a3345..99e4f9c492b6d44b50046fa89d0966483e51dcae 100644
--- a/src/hydrogen.h
+++ b/src/hydrogen.h
@@ -1367,7 +1367,7 @@ class HGraphBuilder {
HValue* capacity);
// array must have been allocated with enough room for
// 1) the JSArray, 2) a AllocationSiteInfo if mode requires it,
// 3) a FixedArray or FixedDoubleArray.
// A pointer to the Fixed(Double)Array is returned.
HInnerAllocatedObject* BuildJSArrayHeader(HValue* array,
@@ -1413,9 +1413,9 @@ class HGraphBuilder {
int position,
HIfContinuation* continuation);
- HValue* BuildCreateAllocationSiteInfo(HValue* previous_object,
- int previous_object_size,
- HValue* payload);
+ HValue* BuildCreateAllocationMemento(HValue* previous_object,
+ int previous_object_size,
+ HValue* payload);
HInstruction* BuildGetNativeContext(HValue* context);
HInstruction* BuildGetArrayFunction(HValue* context);
« no previous file with comments | « src/heap.cc ('k') | src/hydrogen.cc » ('j') | no next file with comments »
@@ -1367,7 +1367,7 @@ class HGraphBuilder {
HValue* capacity);
// array must have been allocated with enough room for
- // 1) the JSArray, 2) a AllocationSiteInfo if mode requires it,
+ // 1) the JSArray, 2) a AllocationMemento if mode requires it,
// 3) a FixedArray or FixedDoubleArray.
// A pointer to the Fixed(Double)Array is returned.

Powered by Google App Engine
This is Rietveld 408576698